@@ -177,13 +177,13 @@ class baseWebBrowserController:
                 # 待機
                 element = self.WebDriverWait(locater)
                 # スクレイピング
-                return self.cbCreateSearchResultDictionaryByWebDriver(element, dfItemInfo, dictItemInfoRowCount)
+                return self.cbCreateSearchResultDictionaryByWebDriver(self, element, dfItemInfo, dictItemInfoRowCount)
             elif self.config.ScrapingType == self.config.settingValueStruct.ScrapingType.beutifulSoup.value:
                 # 待機
                 self.Delay(self.config)
                 # スクレイピング
                 soup:BeautifulSoup = self.scrapingWithBeautifulSoup()
-                return self.cbCreateSearchResultDictionaryByBeutifulSoup(soup, dfItemInfo, dictItemInfoRowCount)
+                return self.cbCreateSearchResultDictionaryByBeutifulSoup(self, soup, dfItemInfo, dictItemInfoRowCount)
     
     @Logger.loggerDecorator('Create SearchResultDictionary By WebDriver')
     def createSearchResultDictionaryByWebDriver(self, element, dfItemInfo:DataFrame, dictItemInfoRowCount:int) -> dict:
